@@ -1,9 +1,13 @@
 """Types and aliases."""
 from typing import Callable, Dict, List, Tuple, Union
+from collections import namedtuple
 
 PreconditionParams = Union[Dict[str, str], Tuple[Tuple[str, str], ...]]
 Cookies = PreconditionParams
 Headers = PreconditionParams
 
 RequestProperty = Union[Union[Dict, None], Union[str, None]]
-MethodsList =  List[Callable[..., None]]
+MethodList =  List[Callable[..., None]]
+
+TestMethod = namedtuple("TestMethod", "function,weight")
+TestMethods = List[TestMethod]
\ No newline at end of file
